@@ -11,6 +11,7 @@ from config import __version__
 new_element = None
 
 # TODO: сделать обработку ref
+# TODO: добавить типы переменных
 
 
 def __dump_json__(file_path, json):
@@ -18,6 +19,14 @@ def __dump_json__(file_path, json):
         file.write(json_dump(json, indent=4))
 
 
+def __wait_confirmation__(message: str) -> bool:
+    print(message)
+    answer = input()
+    if answer.lower() != "yes" and answer.lower() != 'y':
+        return False
+    return True
+
+
 def __parse_element__(element, name_parent_element, parent_element):
     global new_element
     if element['type'] == 'object':
@@ -38,12 +47,8 @@ def __update_add_command__(**kwargs):
         if i not in template['properties']:
             print(f'Элемента {i} нет в шаблоне')
             return
-        if i in config.keys():
-            # TODO: сделать метод для ожидания ввода
-            print(f'{i} элемент уже есть в конфигурации, перезаписать (y/n)')
-            answer = input()
-            if answer.lower() != "yes" and answer.lower() != 'y':
-                continue
+        if i in config.keys() and __wait_confirmation__(f'{i} элемент уже есть в конфигурации, перезаписать (y/n)'):
+            continue
         global new_element
         new_element = {}
         __parse_element__(template['properties'][i], i, new_element)
@@ -129,11 +134,9 @@ def create_command(params):
             message += f"{i}, "
         print(message[:-2])
         return
-    if path_exists(params.config_file):
-        print('Файл конфигурации уже существует, перезаписать его? (y/n)')
-        answer = input()
-        if answer.lower() != "yes" and answer.lower() != 'y':
-            return
+    if path_exists(params.config_file) and \
+            __wait_confirmation__('Файл конфигурации уже существует, перезаписать его? (y/n)'):
+        return
     if params.elements:
         if not getenv('TEMPLATE_CONFIG', default=None):
             print("Не определена переменная окружения TEMPLATE_CONFIG")
